re_id_list = [
    "[A-Za-z0-9]+[\d@]+[\w@]*",
    "[\d@]+[A-Za-z0-9]+[\w@]*",
    "[\d]+[\/\-]*[\w]+[\/\-]*[\w]*", #1673/QĐ-UBND, 50/2014/TT-BGTVT
    "[\d]+[\/\-]+[\d]*[\/\-]*[a-zđ\-\/]+",
    "\d{7,}",
    "[\d.\/\-\.,]{2,}",
    "\d{2}[a-z]{1,3}-\d{2,4}[\.]*\d*",
    "[a-z]+[\-/]\d+",
]